@@ -3,21 +3,23 @@
 """ versionedinitmeta.py
 Description:
 """
-__author__ = "Anthony Fong"
-__copyright__ = "Copyright 2021, Anthony Fong"
-__credits__ = ["Anthony Fong"]
-__license__ = ""
-__version__ = "0.3.0"
-__maintainer__ = "Anthony Fong"
-__email__ = ""
-__status__ = "Prototype"
+# Package Header #
+from ..__header__ import *
 
-# Default Libraries #
+# Header #
+__author__ = __author__
+__credits__ = __credits__
+__maintainer__ = __maintainer__
+__email__ = __email__
 
-# Downloaded Libraries #
+
+# Imports #
+# Standard Libraries #
+
+# Third-Party Packages #
 from baseobjects import InitMeta
 
-# Local Libraries #
+# Local Packages #
 from .versionedmeta import VersionedMeta
 
 
